@@ -7,10 +7,11 @@ A plugin for AiiDA which defines a generic optimization workchain, and
 engines and wrappers for .
 """
 
-__version__ = '0.3.2'
+__version__ = "0.5.0"
 
 from ._optimization_workchain import OptimizationWorkChain
+from . import helpers
 from . import engines
 from . import wrappers
 
-__all__ = ['OptimizationWorkChain', 'engines', 'wrappers']
+__all__ = ["OptimizationWorkChain", "helpers", "engines", "wrappers"]
