@@ -6,8 +6,11 @@
 This module defines optimization routines to be used with the main optimization WorkChain.
 """
 
+from . import base
 from ._bisection import Bisection
+from ._convergence import Convergence
 from ._nelder_mead import NelderMead
 from ._parameter_sweep import ParameterSweep
+from ._particle_swarm import ParticleSwarm
 
-__all__ = ['Bisection', 'NelderMead', 'ParameterSweep']
+__all__ = ['base', 'Bisection', 'NelderMead', 'ParameterSweep', 'Convergence', 'ParticleSwarm']
